summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
-rw-r--r--ChangeLog4
-rw-r--r--kpilot/conduitConfigDialog.cc2
-rw-r--r--kpilot/datebookWidget.cc4
-rw-r--r--kpilot/datebookWidget.h4
-rw-r--r--kpilot/dbSelection_base.ui2
-rw-r--r--kpilot/dbviewerWidget.cc6
-rw-r--r--kpilot/dbviewerWidget.h8
-rw-r--r--kpilot/kpilot.cc30
-rw-r--r--kpilot/kpilot.h4
-rw-r--r--kpilot/listCat.cc8
-rw-r--r--kpilot/listCat.h10
-rw-r--r--kpilot/pilotDaemon.cc6
-rw-r--r--kpilot/todoWidget.cc2
-rw-r--r--kpilot/todoWidget.h4
14 files changed, 47 insertions, 47 deletions
diff --git a/ChangeLog b/ChangeLog
index f663f26..843d168 100644
--- a/ChangeLog
+++ b/ChangeLog
@@ -3332,7 +3332,7 @@ listed here, please let me know.
2001-04-28 Martin Junius <mj@m-j-s.net>
* kpilot/kpilot.cc
- (initMenu): use KToggleAction and setExclusiveGroup for view menu.
+ (initMenu): use TDEToggleAction and setExclusiveGroup for view menu.
(addComponentPage): same here for the other components.
(initMenu): setChecked for view_kpilot action.
@@ -3550,7 +3550,7 @@ indicate when the fix or change was committed.
* Removed some null-conduit comments from the KNotes conduit. [26-2]
* Removed some #include <getopt.h> for Solaris. Cleaned up other
includes as well, just a little. [26-2]
-* Started a change to KActions. [ 1-3]
+* Started a change to TDEActions. [ 1-3]
* Added a new FileInstaller for use in the daemon and the widget. [ 1-3]
It's currently only used by the widget.
* Added listItems.{h,cc} in response to bug #21392; changed address
diff --git a/kpilot/conduitConfigDialog.cc b/kpilot/conduitConfigDialog.cc
index 4cf4526..45b9c35 100644
--- a/kpilot/conduitConfigDialog.cc
+++ b/kpilot/conduitConfigDialog.cc
@@ -144,7 +144,7 @@ ConduitTip::~ConduitTip()
// implement our own check list items so we can detect if a given item was checked/unchecked. We need
// this to prevent the modified signal if one only wants to display a conduit's config widget. Currently,
-// KListView doesn't provide any signal that indicates that the checked state of a checklist item was changed.
+// TDEListView doesn't provide any signal that indicates that the checked state of a checklist item was changed.
class KPilotCheckListItem : public TQCheckListItem
{
public:
diff --git a/kpilot/datebookWidget.cc b/kpilot/datebookWidget.cc
index bc2dff5..db824cd 100644
--- a/kpilot/datebookWidget.cc
+++ b/kpilot/datebookWidget.cc
@@ -64,7 +64,7 @@ DatebookWidget::DatebookWidget(TQWidget *parent, const TQString &dbpath) :
fDeleteButton = new TQPushButton( i18n( "&Delete..." ), this, "pushButton3" );
g->addWidget( fDeleteButton, 2, 2 );
- fEventList = new KListView( this, "kListView1" );
+ fEventList = new TDEListView( this, "kListView1" );
fEventList->addColumn( i18n( "Time" ) );
fEventList->addColumn( i18n( "Al" ) );
fEventList->addColumn( i18n( "Rec" ) );
@@ -72,7 +72,7 @@ DatebookWidget::DatebookWidget(TQWidget *parent, const TQString &dbpath) :
// fEventList->setSizePolicy( TQSizePolicy( (TQSizePolicy::SizeType)7, (TQSizePolicy::SizeType)7, 0, 0, fEventList->sizePolicy().hasHeightForWidth() ) );
fEventList->setAllColumnsShowFocus( TRUE );
fEventList->setShowSortIndicator( TRUE );
- fEventList->setResizeMode( KListView::/*LastColumn*/AllColumns );
+ fEventList->setResizeMode( TDEListView::/*LastColumn*/AllColumns );
fEventList->setFullWidth( TRUE );
// fEventList->setAlternateBackground( TQColor( 221, 146, 240 ) );
g->addMultiCellWidget(fEventList, 0, 2, 3, 3);
diff --git a/kpilot/datebookWidget.h b/kpilot/datebookWidget.h
index c5f4cfc..1cc645c 100644
--- a/kpilot/datebookWidget.h
+++ b/kpilot/datebookWidget.h
@@ -34,7 +34,7 @@
class KDatePicker;
class TQPushButton;
-class KListView;
+class TDEListView;
class DatebookWidget : public PilotComponent
{
@@ -60,7 +60,7 @@ private:
TQPushButton*fAddButton;
TQPushButton*fEditButton;
TQPushButton*fDeleteButton;
- KListView*fEventList;
+ TDEListView*fEventList;
};
diff --git a/kpilot/dbSelection_base.ui b/kpilot/dbSelection_base.ui
index df28a2c..67b6b67 100644
--- a/kpilot/dbSelection_base.ui
+++ b/kpilot/dbSelection_base.ui
@@ -17,7 +17,7 @@
<property name="name">
<cstring>unnamed</cstring>
</property>
- <widget class="KListView" row="0" column="0" rowspan="1" colspan="3">
+ <widget class="TDEListView" row="0" column="0" rowspan="1" colspan="3">
<column>
<property name="text">
<string>Database</string>
diff --git a/kpilot/dbviewerWidget.cc b/kpilot/dbviewerWidget.cc
index dbd4dcc..8cca3e8 100644
--- a/kpilot/dbviewerWidget.cc
+++ b/kpilot/dbviewerWidget.cc
@@ -77,7 +77,7 @@ void GenericDBWidget::setupWidget()
{
TQGridLayout *g = new TQGridLayout( this, 1, 1, SPACING);
- fDBList = new KListBox( this );
+ fDBList = new TDEListBox( this );
g->addWidget( fDBList, 0, 0 );
fDBType = new KComboBox( FALSE, this );
g->addWidget( fDBType, 1, 0 );
@@ -96,13 +96,13 @@ void GenericDBWidget::setupWidget()
g1->addWidget( fAppInfoButton, 2, 0 );
TQGridLayout *g2 = new TQGridLayout( 0, 1, 1);
- fRecordList = new KListView( this );
+ fRecordList = new TDEListView( this );
g2->addMultiCellWidget( fRecordList, 0, 0, 0, 2 );
fRecordList->addColumn(i18n("Rec. Nr."));
fRecordList->addColumn(i18n("Length"));
fRecordList->addColumn(i18n("Record ID"));
fRecordList->setAllColumnsShowFocus(true);
- fRecordList->setResizeMode( KListView::LastColumn );
+ fRecordList->setResizeMode( TDEListView::LastColumn );
fRecordList->setFullWidth( TRUE );
fRecordList->setItemsMovable( FALSE );
diff --git a/kpilot/dbviewerWidget.h b/kpilot/dbviewerWidget.h
index 17b75bb..5d2c30c 100644
--- a/kpilot/dbviewerWidget.h
+++ b/kpilot/dbviewerWidget.h
@@ -32,13 +32,13 @@
#include "pilotComponent.h"
-class KListBox;
+class TDEListBox;
class KTextEdit;
class KPushButton;
class KComboBox;
class PilotLocalDatabase;
class PilotRecord;
-class KListView;
+class TDEListView;
class GenericDBWidget : public PilotComponent
{
@@ -71,11 +71,11 @@ protected slots:
void writeRecord(PilotRecord*r);
private:
- KListBox*fDBList;
+ TDEListBox*fDBList;
KComboBox*fDBType;
KTextEdit*fDBInfo;
KPushButton*fDBInfoButton, *fAppInfoButton;
- KListView*fRecordList;
+ TDEListView*fRecordList;
KPushButton*fAddRecord, *fEditRecord, *fDeleteRecord;
enum eDBType {
diff --git a/kpilot/kpilot.cc b/kpilot/kpilot.cc
index 0878a98..1ac9be7 100644
--- a/kpilot/kpilot.cc
+++ b/kpilot/kpilot.cc
@@ -97,7 +97,7 @@ public:
KPilotInstaller::KPilotInstaller() :
DCOPObject("KPilotIface"),
- KMainWindow(0),
+ TDEMainWindow(0),
fDaemonStub(new PilotDaemonDCOP_stub("kpilotDaemon",
"KPilotDaemonIface")),
fP(new KPilotPrivate),
@@ -508,11 +508,11 @@ void KPilotInstaller::initMenu()
{
FUNCTIONSETUP;
- KAction *a;
+ TDEAction *a;
- KActionMenu *syncPopup;
+ TDEActionMenu *syncPopup;
- syncPopup = new KActionMenu(i18n("HotSync"), CSL1("kpilot"),
+ syncPopup = new TDEActionMenu(i18n("HotSync"), CSL1("kpilot"),
actionCollection(), "popup_hotsync");
syncPopup->setToolTip(i18n("Select the kind of HotSync to perform next."));
syncPopup->setWhatsThis(i18n("Select the kind of HotSync to perform next. "
@@ -522,7 +522,7 @@ void KPilotInstaller::initMenu()
TQT_TQOBJECT(this), TQT_SLOT(slotHotSyncRequested()));
// File actions, keep this list synced with kpilotui.rc and pilotDaemon.cc
- a = new KAction(i18n("&HotSync"), CSL1("hotsync"), 0,
+ a = new TDEAction(i18n("&HotSync"), CSL1("hotsync"), 0,
TQT_TQOBJECT(this), TQT_SLOT(slotHotSyncRequested()),
actionCollection(), "file_hotsync");
a->setToolTip(i18n("Next HotSync will be normal HotSync."));
@@ -530,7 +530,7 @@ void KPilotInstaller::initMenu()
"should be a normal HotSync."));
syncPopup->insert(a);
- a = new KAction(i18n("Full&Sync"), CSL1("fullsync"), 0,
+ a = new TDEAction(i18n("Full&Sync"), CSL1("fullsync"), 0,
TQT_TQOBJECT(this), TQT_SLOT(slotFullSyncRequested()),
actionCollection(), "file_fullsync");
a->setToolTip(i18n("Next HotSync will be a FullSync."));
@@ -538,7 +538,7 @@ void KPilotInstaller::initMenu()
"should be a FullSync (check data on both sides)."));
syncPopup->insert(a);
- a = new KAction(i18n("&Backup"), CSL1("backup"), 0,
+ a = new TDEAction(i18n("&Backup"), CSL1("backup"), 0,
TQT_TQOBJECT(this), TQT_SLOT(slotBackupRequested()),
actionCollection(), "file_backup");
a->setToolTip(i18n("Next HotSync will be backup."));
@@ -546,7 +546,7 @@ void KPilotInstaller::initMenu()
"should back up the Handheld to the PC."));
syncPopup->insert(a);
- a = new KAction(i18n("&Restore"), CSL1("restore"), 0,
+ a = new TDEAction(i18n("&Restore"), CSL1("restore"), 0,
TQT_TQOBJECT(this), TQT_SLOT(slotRestoreRequested()),
actionCollection(), "file_restore");
a->setToolTip(i18n("Next HotSync will be restore."));
@@ -554,7 +554,7 @@ void KPilotInstaller::initMenu()
"should restore the Handheld from data on the PC."));
syncPopup->insert(a);
- a = new KAction(i18n("Copy Handheld to PC"), TQString(), 0,
+ a = new TDEAction(i18n("Copy Handheld to PC"), TQString(), 0,
TQT_TQOBJECT(this), TQT_SLOT(slotHHtoPCRequested()),
actionCollection(), "file_HHtoPC");
a->setToolTip(i18n("Next HotSync will be backup."));
@@ -563,7 +563,7 @@ void KPilotInstaller::initMenu()
"overwriting entries on the PC."));
syncPopup->insert(a);
- a = new KAction(i18n("Copy PC to Handheld"), TQString(), 0,
+ a = new TDEAction(i18n("Copy PC to Handheld"), TQString(), 0,
TQT_TQOBJECT(this), TQT_SLOT(slotPCtoHHRequested()),
actionCollection(), "file_PCtoHH");
a->setToolTip(i18n("Next HotSync will copy PC to Handheld."));
@@ -574,7 +574,7 @@ void KPilotInstaller::initMenu()
#if 0
- a = new KAction(i18n("&List Only"),CSL1("listsync"),0,
+ a = new TDEAction(i18n("&List Only"),CSL1("listsync"),0,
this,TQT_SLOT(slotTestSyncRequested()),
actionCollection(), "file_list");
a->setToolTip(i18n("Next HotSync will list databases."));
@@ -585,7 +585,7 @@ void KPilotInstaller::initMenu()
#endif
- a = new KAction(i18n("Rese&t Link"),CSL1("reload"), 0,
+ a = new TDEAction(i18n("Rese&t Link"),CSL1("reload"), 0,
TQT_TQOBJECT(this), TQT_SLOT(slotResetLink()),
actionCollection(),"file_reload");
a->setToolTip(i18n("Reset the device connection."));
@@ -610,7 +610,7 @@ void KPilotInstaller::initMenu()
(void) KStdAction::preferences(TQT_TQOBJECT(this), TQT_SLOT(configure()),
actionCollection());
- a = new KAction(i18n("Configuration &Wizard..."), CSL1("wizard"), 0,
+ a = new TDEAction(i18n("Configuration &Wizard..."), CSL1("wizard"), 0,
TQT_TQOBJECT(this), TQT_SLOT(configureWizard()),
actionCollection(), "options_configure_wizard");
a->setWhatsThis(i18n("Configure KPilot using the configuration wizard."));
@@ -683,8 +683,8 @@ void KPilotInstaller::addComponentPage(PilotComponent * p,
strlcat(actionname, componentname, actionnameLength);
}
- KToggleAction *pt =
- new KToggleAction(name, /* "kpilot" -- component icon, */ 0,
+ TDEToggleAction *pt =
+ new TDEToggleAction(name, /* "kpilot" -- component icon, */ 0,
TQT_TQOBJECT(p), TQT_SLOT(slotShowComponent()),
actionCollection(), actionname);
diff --git a/kpilot/kpilot.h b/kpilot/kpilot.h
index 9d7065c..e270d3a 100644
--- a/kpilot/kpilot.h
+++ b/kpilot/kpilot.h
@@ -34,7 +34,7 @@
class TQPopupMenu;
class TQComboBox;
-class KAction;
+class TDEAction;
class KProgress;
class KJanusWidget;
@@ -47,7 +47,7 @@ class LogWidget;
-class KPilotInstaller : public KMainWindow, public KPilotDCOP
+class KPilotInstaller : public TDEMainWindow, public KPilotDCOP
{
Q_OBJECT
diff --git a/kpilot/pilotDaemon.cc b/kpilot/pilotDaemon.cc
index aa6bea5..06926d1 100644
--- a/kpilot/pilotDaemon.cc
+++ b/kpilot/pilotDaemon.cc
@@ -121,7 +121,7 @@ PilotDaemonTray::PilotDaemonTray(PilotDaemon * p) :
{
case Qt::RightButton:
{
- KPopupMenu *menu = contextMenu();
+ TDEPopupMenu *menu = contextMenu();
contextMenuAboutToShow(menu);
menu->popup(e->globalPos());
}
@@ -152,7 +152,7 @@ void PilotDaemonTray::setupWidget()
slotShowNotListening();
TQTimer::singleShot(2000,this,TQT_SLOT(slotShowNormal()));
- KPopupMenu *menu = contextMenu();
+ TDEPopupMenu *menu = contextMenu();
menuKPilotItem = menu->insertItem(i18n("Start &KPilot"), daemon,
TQT_SLOT(slotRunKPilot()));
@@ -160,7 +160,7 @@ void PilotDaemonTray::setupWidget()
daemon, TQT_SLOT(slotRunConfig()));
menu->insertSeparator();
- fSyncTypeMenu = new KPopupMenu(menu,"sync_type_menu");
+ fSyncTypeMenu = new TDEPopupMenu(menu,"sync_type_menu");
TQString once = i18n("Appended to names of sync types to indicate the sync will happen just one time"," (once)");
#define MI(a) fSyncTypeMenu->insertItem( \
SyncAction::SyncMode::name(SyncAction::SyncMode::a) + once, \
diff --git a/kpilot/todoWidget.cc b/kpilot/todoWidget.cc
index e717a9d..e2bcb8a 100644
--- a/kpilot/todoWidget.cc
+++ b/kpilot/todoWidget.cc
@@ -224,7 +224,7 @@ void TodoWidget::setupWidget()
fListBox = new TodoListView(this);
fListBox->addColumn( i18n( "To-do Item" ) );
fListBox->setAllColumnsShowFocus( TRUE );
- fListBox->setResizeMode( KListView::LastColumn );
+ fListBox->setResizeMode( TDEListView::LastColumn );
fListBox->setFullWidth( TRUE );
fListBox->setItemsMovable( FALSE );
fListBox->setItemsRenameable (TRUE);
diff --git a/kpilot/todoWidget.h b/kpilot/todoWidget.h
index 0651092..46432f3 100644
--- a/kpilot/todoWidget.h
+++ b/kpilot/todoWidget.h
@@ -38,12 +38,12 @@ class TQTextView;
#include "pilotTodoEntry.h"
#include "listItems.h"
-class TodoListView : public KListView
+class TodoListView : public TDEListView
{
Q_OBJECT
public:
- TodoListView(TQWidget * parent = 0, const char * name = 0 ):KListView(parent, name){};
+ TodoListView(TQWidget * parent = 0, const char * name = 0 ):TDEListView(parent, name){};
~TodoListView() {};
signals:
void itemChecked(TQCheckListItem*item);
diff --git a/kpilot/listCat.cc b/kpilot/listCat.cc
index 64088c5..6f32f35 100644
--- a/kpilot/listCat.cc
+++ b/kpilot/listCat.cc
@@ -2,7 +2,7 @@
**
** Copyright (C) 2000-2001 by Adriaan de Groot
**
** This file defines a specialization of KListView that can
** be used to sort some fixed set of object into some fixed
** set of categories.
*/
@@ -38,7 +38,7 @@
ListCategorizer::ListCategorizer(TQWidget * parent,
const char *name) :
- KListView(parent, name),
+ TDEListView(parent, name),
fStartOpen(false)
{
FUNCTIONSETUP;
@@ -49,7 +49,7 @@ ListCategorizer::ListCategorizer(const TQStringList & i,
bool startOpen,
TQWidget * parent,
const char *name) :
- KListView(parent, name),
+ TDEListView(parent, name),
fStartOpen(startOpen)
{
FUNCTIONSETUP;
@@ -139,7 +139,7 @@ void ListCategorizer::setupWidget()
if (!p || !p->parent())
return;
- KListView::startDrag();
+ TDEListView::startDrag();
}
TQStringList ListCategorizer::listSiblings(const TQListViewItem * p, int column) const
@@ -2,7 +2,7 @@
** Copyright (C) 2000-2001 by Adriaan de Groot
**
-** This file defines a specialization of KListView that can
+** This file defines a specialization of TDEListView that can
** be used to sort some fixed set of object into some fixed
** set of categories.
diff --git a/kpilot/listCat.h b/kpilot/listCat.h
index 32c808a..d844692 100644
--- a/kpilot/listCat.h
+++ b/kpilot/listCat.h
@@ -8,7 +8,7 @@
*/
/** @file
** This is a specialization of KListView to allow the user to
** DnD a fixed set of objects into a fixed set of categories
** (categories set at construction time). @em Deprecated, do not use.
*/
@@ -38,13 +38,13 @@
class TQStringList;
/**
* This Widget extends KListView for a particular purpose:
* sorting some items into some bins. This can be useful
* for putting items in an enabled / disabled state, or
* into categories, or configuring toolbars (putting
* icons onto toolbars).
*
* You can use all of the standard KListView signals and
* slots. You may in particular want to change the names
* of the columns, for example:
* @code
@@ -61,7 +61,7 @@ class TQStringList;
* @version $Id$
*/
-class ListCategorizer : public KListView
+class ListCategorizer : public TDEListView
{
Q_OBJECT
@@ -189,7 +189,7 @@ protected:
private:
/**
* Call several KListView functions to set up useful
* behavior for this particular class.
*/
void setupWidget();
@@ -8,7 +8,7 @@
*/
/** @file
-** This is a specialization of KListView to allow the user to
+** This is a specialization of TDEListView to allow the user to
** DnD a fixed set of objects into a fixed set of categories
** (categories set at construction time). @em Deprecated, do not use.
@@ -38,13 +38,13 @@
class TQStringList;
/**
- * This Widget extends KListView for a particular purpose:
+ * This Widget extends TDEListView for a particular purpose:
* sorting some items into some bins. This can be useful
* for putting items in an enabled / disabled state, or
@@ -38,13 +38,13 @@
* icons onto toolbars).
*
- * You can use all of the standard KListView signals and
+ * You can use all of the standard TDEListView signals and
* slots. You may in particular want to change the names
* of the columns, for example:
@@ -189,7 +189,7 @@ protected:
private:
/**
- * Call several KListView functions to set up useful
+ * Call several TDEListView functions to set up useful
* behavior for this particular class.
*/